<?php

class Rpsmdw_Front extends Rpsmdw_Main {

    public function __construct() {
	parent::__construct();
	if($this->getSetting('enable_cart') || $this->getSetting('enable_checkout')){
	    add_action('plugins_loaded',array( $this,"initFrondEnd" ),11);
	    add_action('init',array( $this,'initAction' ));
	}
    }

    public function initAction() {
	load_plugin_textdomain(self::$taxdomain,false,dirname(plugin_basename(__FILE__)).'/../lang/');
    }

    public function initFrondEnd() {
	/* hook for register front css and js */
	add_filter('woocommerce_cart_shipping_method_full_label',array( $this,'displayDeliveryText' ),10,2);
	add_action("wp_enqueue_scripts",array( $this,"enqueueScripts" ),100);
    }

    public function displayDeliveryText($label,$method) {

	if((is_cart() && !$this->getSetting('enable_cart'))){
	    return $label;
	}
	if((is_checkout() && !$this->getSetting('enable_checkout'))){
	    return $label;
	}
	$label = $this->getShippingMethodText($label,$method);
	return $label;
    }

    public function getShippingMethodSettings($label,$method) {
	$shippingSetting = $this->getSetting('shipping');
	$shippingMethodSetting = isset($shippingSetting[$method->id]) ? $shippingSetting[$method->id] : "";
	if(!empty($shippingMethodSetting)){
	    return $shippingMethodSetting;
	}
	$methodArr = explode(":",$method->id);
	if(count($methodArr) >= 3){
	    $methodFinal = $methodArr[0] . ":" . $methodArr[1];
	    $shippingMethodSetting = isset($shippingSetting[$methodFinal]) ? $shippingSetting[$methodFinal] : "";
	    if(!empty($shippingMethodSetting)){
		return $shippingMethodSetting;
	    }
	}
	$methodArr = explode(">",$method->id);
	if(count($methodArr) >= 2){
	    $methodFinal = $methodArr[0];
	    $shippingMethodSetting = isset($shippingSetting[$methodFinal]) ? $shippingSetting[$methodFinal] : "";
	    if(!empty($shippingMethodSetting)){
		return $shippingMethodSetting;
	    }
	}
	$methodArr = explode("_",$method->id);
	if(count($methodArr) >= 2){
	    $methodFinal = $methodArr[0];
            foreach($shippingSetting as $key=>$value){
                if(strpos($key,$methodFinal)!==false){
                    $shippingMethodSetting=$value;
                    break;
                }
            }
	    if(!empty($shippingMethodSetting)){
		return $shippingMethodSetting;
	    }
	}
	return array();
    }

    public function getShippingMethodText($label,$method) {

	$shippingMethodSetting = $this->getShippingMethodSettings($label,$method);
	if(!empty($shippingMethodSetting)){
	    $icon = "";
	    $desc = "";
	    if(isset($shippingMethodSetting['icon']) && $shippingMethodSetting['icon'] != ""){
		$icon = $shippingMethodSetting['icon'];
	    }
	    if(isset($shippingMethodSetting['desc']) && $shippingMethodSetting['desc'] != ""){
		$desc = $shippingMethodSetting['desc'];
	    }

	    $iconHtml = $this->getShippingTextWithIcon($icon);
	    $descHtml = $this->getShippingTextWithDesc($desc);
	    $descPoistion = $this->getSetting('desc_position');
	    $iconPoistion = $this->getSetting('icon_position');
	    $label = "<span class='rpsmdw_shipping_title'>" . $label . "</span>";
	    if($iconPoistion == 0 && $descPoistion == 1){
		$finalText = $iconHtml . '<span class="rpsmdw_title_desc_container">' . $label . $descHtml . '</span>';
	    } else if($iconPoistion == 0 || $iconPoistion == 1){
		$finalText = ($iconPoistion == 0) ? $iconHtml . $label : $label . $iconHtml;
		$finalText = ($descPoistion == 0) ? $descHtml . $finalText : $finalText . $descHtml;
	    } else if($iconPoistion == 2 || $iconPoistion == 3){
		$finalText = ($iconPoistion == 2) ? $iconHtml . $descHtml : $descHtml . $iconHtml;
		$finalText = ($descPoistion == 0) ? $finalText . $label : $label . $finalText;
	    }


	    return "<span class='rpsmdw_shipping_container'>" . $finalText . "</span>";
	}
	return $label;
    }

    public function getShippingTextWithDesc($desc) {

	if(empty($desc)){
	    return '';
	}
	$descHtml = "<span class='rpsmdw_desc'>" . stripslashes($desc) . "</span>";
	return $descHtml;
    }

    public function getShippingTextWithIcon($icon) {

	if(empty($icon)){
	    return '';
	}

	$imgSrc = wp_get_attachment_image_src($icon,'full');
	$imgSrc = isset($imgSrc[0]) ? $imgSrc[0] : "";

	if(empty($imgSrc)){
	    return '';
	}
	$iconHtml = "<span class='rpsmdw_icon'><img src='" . esc_url($imgSrc) . "' alt='' /></span>";
	return $iconHtml;
    }

    /**
     * Function for register  js and css
     */
    public function enqueueScripts() {
	wp_register_style('rpsmdw-style-handle',false);
	wp_enqueue_style('rpsmdw-style-handle');


	$inlineCss = '.rpsmdw_shipping_container .rpsmdw_title_desc_container{display: inline-block;margin-left: 5px;}.rpsmdw_shipping_container .rpsmdw_icon{display:inline-block;margin:3px;vertical-align:top;}.rpsmdw_shipping_container .rpsmdw_desc{display:block;color:' . $this->getSetting('text_color') . ' !important;font-size:' . $this->getSetting('text_size') . 'px !important;}';
	if(!empty($this->getSetting('icon_width')) || !empty($this->getSetting('icon_height'))){
	    $inlineCss .= '.rpsmdw_shipping_container .rpsmdw_icon img{';
	    if(!empty($this->getSetting('icon_width'))){
		$inlineCss .= "max-width:" . $this->getSetting('icon_width') . "px;";
	    }
	    if(!empty($this->getSetting('icon_height'))){
		$inlineCss .= "max-height:" . $this->getSetting('icon_height') . "px;";
	    }
	    $inlineCss .= '}';
	}
	$inlineCss .= $this->getSetting('custom_css');
	wp_add_inline_style('rpsmdw-style-handle',$inlineCss);
    }

}
